/****************************************************************************
**
** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef MERCONNECTIONMANAGER_H
#define MERCONNECTIONMANAGER_H

#include <ssh/sshconnectionmanager.h>
#include <ssh/sshconnection.h>

#include <QObject>

namespace QSsh {
class SshRemoteProcessRunner;
}

namespace Mer {
namespace Internal {

class MerConnectionManager : public QObject
{
    Q_OBJECT
public:
    enum Errors
    {
        NoError,
        KeyGenError,
        PrivKeyCreateError,
        PubKeyCreateError,
        PubKeyReadError,
        AuthKeysReadError,
        AuthKeysAppendError
    };

    static MerConnectionManager *instance();

    QSsh::SshConnection* acquireConnection();
    void releaseConnection(QSsh::SshConnection* connection);

    void executeCommand(const QByteArray &command);

    QSsh::SshConnectionParameters sshConnectionParameters() const;
    void setSshConnectionParameters(const QSsh::SshConnectionParameters &params);
    void updateSshConnectionParameters();
    int createAndAuthorizeSshKeyIfNeeded(const QString &sharedHome, QString &errorMessage);

    QByteArray readAllStandardOutput();
    QByteArray readAllStandardError();

signals:
    void remoteProcessConnectionError();
    void remoteProcessStarted();
    void remoteProcessReadReadyStandardOutput();
    void remoteProcessReadReadyStandardError();
    void remoteProcessClosed(int exitStatus);

public:
    explicit MerConnectionManager();
    ~MerConnectionManager();
    MerConnectionManager(const MerConnectionManager &);
    MerConnectionManager &operator=(const MerConnectionManager &);

private:
    static MerConnectionManager *m_connectionManager;
    QSsh::SshConnectionManager &m_sshConnectionManager;
    QSsh::SshConnectionParameters m_sshConnectionParameters;
    QSsh::SshRemoteProcessRunner *m_sshRemoteProcessRunner;
};

} // Internal
} // Mer

#endif // MERCONNECTIONMANAGER_H
