/****************************************************************************
**
** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef MERKITMANAGER_H
#define MERKITMANAGER_H

#include "vmsettings.h"
#include "vboxmanage.h"

#include <QObject>

namespace Mer {
namespace Internal {

class MerKitManagerPrivate;
class MerKitManager : public QObject
{
    Q_OBJECT
public:
    enum State {
        Idle,
        CreateKit,
        RemoveKit,
        CheckVM,
        VMIsRunning,
        VMRunError,
        CreateScripts,
        RemoveScripts,
        ScriptsCreated,
        ScriptsCreateError,
        AddQtVersion,
        RemoveQtVersion,
        QtVersionAdded,
        AddQtVersionError,
        RegisterToolChain,
        DeregisterToolChain,
        ToolChainRegistered,
        RegisterToolChainError,
        RegisterKit,
        DeregisterKit,
        KitRegistered,
        RegisterKitError,
        Done
    };

    static MerKitManager *instance();
    void createKit(const QString &targetName, const QString &sysRoot);
    void removeKit(const QString &targetName);
    void setWorkingDirectory(const QString &workingDirectory);

    static void updateVMConfig(const VMInfo &info);

    static QString devToolsDirectory();

signals:
    void progress(const QString &msg, int progress, bool success);

private slots:
    void changeState();
    void vBoxProgress(const QString &msg, int progressValue, bool success);

private:
    explicit MerKitManager();
    ~MerKitManager();
    MerKitManager(const MerKitManager &);
    MerKitManager &operator=(const MerKitManager &);

    void checkVM();
    void createScripts();
    bool removeScripts();
    void addQtVersion();
    void removeQtVersion();
    void registerToolChain();
    void deregisterToolChain();
    void registerKit();
    void deregisterKit();
    void resetState();
    static void updateVMConfig(const QMap<QString, QString> &map);

private:
    static MerKitManager *m_kitManager;
    MerKitManagerPrivate *d;
    friend class MerKitManagerPrivate;
};

} // Internal
} // Mer

#endif // MERKITMANAGER_H
