/****************************************************************************
**
** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#include "mermanagementwebview.h"
#include "ui_mermanagementwebview.h"

namespace Mer {
namespace Internal {

MerManagementWebView::MerManagementWebView(QWidget *parent)
    : QWidget(parent)
    , ui(new Ui::MerManagementWebView)
{
    ui->setupUi(this);
    connect(ui->webView->page(), SIGNAL(linkHovered(QString,QString,QString)), ui->statusBarLabel, SLOT(setText(QString)));
    connect(ui->webView->page(), SIGNAL(loadFinished(bool)), SLOT(handleLoadFinished(bool)));
    on_homeButton_clicked();
}

MerManagementWebView::~MerManagementWebView()
{
    delete ui;
}

void MerManagementWebView::setUrl(const QUrl &url)
{
    ui->webView->setUrl(url);
}

void MerManagementWebView::on_webView_urlChanged(const QUrl &url)
{
    ui->urlLineEdit->setText(url.toString());
    ui->statusBarLabel->clear();
}

void MerManagementWebView::on_urlLineEdit_returnPressed()
{
    setUrl(QUrl::fromUserInput(ui->urlLineEdit->text()));
}

void MerManagementWebView::on_homeButton_clicked()
{
    setUrl(QUrl(QLatin1String("http://127.0.0.1:8080/")));
}

void MerManagementWebView::handleLoadFinished(bool success)
{
    if (!success && ui->webView->url().toString().indexOf(QLatin1String("127.0.0.1:8080")) != -1) {
        ui->webView->setHtml(
                    QLatin1String(
                        "<html>"
                        "<head></head>"
                        "<body>"
                        "The SDK VM is not responding - check it's running and check the NAT config as per this wiki page: <a href=\"https://wiki.merproject.org/wiki/Platform_SDK_on_VirtualBox#Setting_up_and_Networking\">https://wiki.merproject.org/wiki/Platform_SDK_on_VirtualBox</a>."
                        "<br/>Afterwards, reload the page by clicking the Mer icon above."
                        "</body>"
                        "</html>")
                    );
    }
}

} // namespace Internal
} // namespace Mer
