/****************************************************************************
**
** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#include "merqtversion.h"
#include "merconstants.h"
#include "merqtparser.h"

#include <QCoreApplication>
#include <qtsupport/qtsupportconstants.h>
#include <utils/environment.h>

namespace Mer {

///////////////////////////////////////////////////////////////////////
//
// MerQtVersion
//
///////////////////////////////////////////////////////////////////////

MerQtVersion::MerQtVersion()
    : QtSupport::BaseQtVersion()
{

}

MerQtVersion::MerQtVersion(const Utils::FileName &path, bool isAutodetected,
                           const QString &autodetectionSource)
    : QtSupport::BaseQtVersion(path, isAutodetected, autodetectionSource)
{

}

MerQtVersion::~MerQtVersion()
{

}

QString MerQtVersion::type() const
{
    return QLatin1String(Constants::MER_QT);
}

MerQtVersion *MerQtVersion::clone() const
{
    return new MerQtVersion(*this);
}

QList<ProjectExplorer::Abi> MerQtVersion::detectQtAbis() const
{
    return qtAbisFromLibrary(qtCorePath(versionInfo(), qtVersionString()));
}

QString MerQtVersion::description() const
{
    return QCoreApplication::translate("QtVersion", "Mer ", "Qt Version is meant for Mer");
}

bool MerQtVersion::supportsShadowBuilds() const
{
    return false;
}

QString MerQtVersion::platformName() const
{
    return QLatin1String(QtSupport::Constants::MER_PLATFORM);
}

QString MerQtVersion::platformDisplayName() const
{
    return QLatin1String(QtSupport::Constants::MER_PLATFORM_TR);
}

void MerQtVersion::addToEnvironment(const ProjectExplorer::Kit *k, Utils::Environment &env) const
{
    BaseQtVersion::addToEnvironment(k, env);
    Utils::FileName cacheDir = qmakeCommand().parentDir();
    env.prependOrSet(QLatin1String("CACHEDIR"), cacheDir.toUserOutput());
}

ProjectExplorer::IOutputParser *MerQtVersion::createOutputParser() const
{
    return new MerQtParser;
}

} // namespace Mer
