/****************************************************************************
**
** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#include "merqtversionfactory.h"
#include "merqtversion.h"
#include "merconstants.h"
#include "merkitmanager.h"

#include <utils/qtcassert.h>

#include <QFileInfo>
#include <QDesktopServices>

namespace Mer {
namespace Internal {

MerQtVersionFactory::MerQtVersionFactory(QObject *parent)
    : QtSupport::QtVersionFactory(parent)
{
}

MerQtVersionFactory::~MerQtVersionFactory()
{

}

bool MerQtVersionFactory::canRestore(const QString &type)
{
    return type == QLatin1String(Constants::MER_QT);
}

QtSupport::BaseQtVersion *MerQtVersionFactory::restore(const QString &type,
    const QVariantMap &data)
{
    QTC_ASSERT(canRestore(type), return 0);
    MerQtVersion *v = new MerQtVersion;
    v->fromMap(data);
    return v;
}

int MerQtVersionFactory::priority() const
{
    return 50;
}

QtSupport::BaseQtVersion *MerQtVersionFactory::create(const Utils::FileName &qmakeCommand,
                                                      ProFileEvaluator *evaluator,
                                                      bool isAutoDetected,
                                                      const QString &autoDetectionSource)
{
    Q_UNUSED(evaluator);

    QFileInfo fi = qmakeCommand.toFileInfo();
    if (!fi.exists() || !fi.isExecutable() || !fi.isFile())
        return 0;

    // Check for the location of qmake
    if (!qmakeCommand.toString().contains(MerKitManager::devToolsDirectory()))
        return 0;
    return new MerQtVersion(qmakeCommand, isAutoDetected, autoDetectionSource);

}

} // Internal
} // Mer

