/****************************************************************************
**
** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#include "mertoolchain.h"
#include "mertoolchainfactory.h"
#include "merconstants.h"
#include "merkitmanager.h"

#include <utils/environment.h>
#include <utils/qtcassert.h>
#include <qtsupport/qtversionmanager.h>

#include <QCoreApplication>
#include <QDir>
#include <QDesktopServices>

namespace Mer {

using namespace ProjectExplorer;

MerToolChain::MerToolChain(bool autodetected) :
    GccToolChain(QLatin1String(Constants::MER_TOOLCHAIN_ID), autodetected)
{}

QString MerToolChain::type() const
{
    return QLatin1String("sb2");
}

QString MerToolChain::typeDisplayName() const
{
    return QCoreApplication::tr("SB2 GCC");
}

QString MerToolChain::makeCommand(const Utils::Environment &environment) const
{
    QString make;
#if defined(Q_OS_WIN)
//    make = QLatin1String("make.bat");
#else
    make = QLatin1String("make");
#endif
    QString makePath = environment.searchInPath(make);
    if (!makePath.isEmpty())
        return makePath;

    return make;
}

QList<Utils::FileName> MerToolChain::suggestedMkspecList() const
{
    return QList<Utils::FileName>(); // Note: Not supported by Qt yet, so default to the mkspec the Qt was build with
}

ToolChain *MerToolChain::clone() const
{
    return new MerToolChain(*this);
}

namespace Internal {

///////////////////////////////////////////////////////////////////////
//
// MerToolChainFactory
//
///////////////////////////////////////////////////////////////////////

QString MerToolChainFactory::displayName() const
{
    return tr("SB2");
}

QString MerToolChainFactory::id() const
{
    return QLatin1String(Constants::MER_TOOLCHAIN_ID);
}

QList<ToolChain *> MerToolChainFactory::autoDetect()
{
    QList<ToolChain *> result;

    // return all tool chains in the mer developer tools directory
    QDir parentDir(MerKitManager::devToolsDirectory());
    QFileInfoList targets = parentDir.entryInfoList(QDir::Dirs|QDir::NoDotAndDotDot);
    foreach (const QFileInfo &target, targets) {
        QDir targetDir(target.absoluteFilePath());
        QFileInfoList gcc = targetDir.entryInfoList(QStringList() << QLatin1String("gcc"),
                                                    QDir::Files);
        if (gcc.count()) {
            MerToolChain *tc = new MerToolChain(true);
            tc->setCompilerCommand(Utils::FileName(gcc.first()));
            tc->setDisplayName(tc->typeDisplayName() +
                               QString(QLatin1String(" %1")).arg(target.baseName()));

            result.append(tc);
        }
    }

    return result;
}

bool MerToolChainFactory::canRestore(const QVariantMap &data)
{
    return idFromMap(data).startsWith(QLatin1String(Constants::MER_TOOLCHAIN_ID) + QLatin1Char(':'));
}

ToolChain *MerToolChainFactory::restore(const QVariantMap &data)
{
    MerToolChain *tc = new MerToolChain(true);
    if (tc->fromMap(data))
        return tc;

    delete tc;
    return 0;
}

} // Internal
} // Mer
