/****************************************************************************
**
** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef TARGETOPTIONSPAGE_H
#define TARGETOPTIONSPAGE_H

#include "meroptionspage.h"
#include "targetsettings.h"

#include <QWidget>
#include <QIcon>

QT_BEGIN_NAMESPACE
class QTreeWidgetItem;
QT_END_NAMESPACE

namespace Mer {
namespace Internal {

namespace Ui { class TargetOptionsPage; }

class TargetOptionsWidget;
class TargetOptionsPage : public MerOptionsPage
{
public:
    explicit TargetOptionsPage(QObject *parent = 0);

    QWidget *createPage(QWidget *parent);
    void apply();
    void finish() { }
    bool matches(const QString &key) const;

    TargetSettings settings() const { return m_settings; }

private:
    TargetOptionsWidget *m_widget;
    TargetSettings m_settings;
    QString m_searchKeyWords;
};

class TargetOptionsWidget : public QWidget
{
    Q_OBJECT

public:
    explicit TargetOptionsWidget(QWidget *parent = 0);
    ~TargetOptionsWidget();

    TargetSettings settings() const;
    void setSettings(const TargetSettings &s);

    QString searchKeyWordMatchString() const;

public slots:
    void onProgress(const QString &msg, int progress, bool success);

private slots:
    void addTarget();
    void removeTarget();

private:
    void updateButtons();
    void fetchQmakeParams();

private:
    Ui::TargetOptionsPage *m_ui;
    QIcon m_invalidTargetIcon;
    QIcon m_validTargetIcon;
};

} // Internal
} // Mer

#endif // TARGETOPTIONSPAGE_H
