/****************************************************************************
**
** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#include "targetsettings.h"
#include "merconstants.h"

#include <QSettings>
#include <QStringList>

namespace Mer {
namespace Internal {

const char TARGETS_GROUP[] = "Mer.Options.Targets";

void TargetSettings::toSettings(QSettings *s) const
{
    s->beginGroup(QLatin1String(TARGETS_GROUP));
    s->remove(QLatin1String(""));
    QHashIterator<QString, QVariantList> i(targets);
    while (i.hasNext()) {
        i.next();
        s->setValue(i.key(), i.value());
    }
    s->endGroup();
}

void TargetSettings::fromSettings(QSettings *s)
{
    s->beginGroup(QLatin1String(TARGETS_GROUP));
    QStringList keys = s->childKeys();
    foreach (const QString &key, keys) {
       targets.insert(key, s->value(key).toList());
    }
    s->endGroup();
}

bool TargetSettings::equals(const TargetSettings &rhs) const
{
    return targets == rhs.targets;
}

} // Internal
} // Mer
