#ifndef VBOXMANAGE_H
#define VBOXMANAGE_H

#include <ssh/sshconnection.h>

#include <QObject>

namespace Mer {
namespace Internal {

class VBoxManagePrivate;
class VMInfo
{
public:
    QString sharedHome;
    quint16 sshPort;
};

class VBoxManage : public QObject
{
    Q_OBJECT
public:
    enum State {
        Idle = 0,
        CheckRegistered = 1,
        GetVMInfo = 2,
        CheckRunning = 3,
        Starting = 4,
        Running = 5,
        Connecting = 6,
        Done = 7
    };

    explicit VBoxManage(QObject *parent = 0);
    ~VBoxManage();

    void testSshConnection(const QString &vmName);

    bool isVMRunning(const QString &vmName);
    bool isVMRegistered(const QString &vmName);
    bool getVMInfo(const QString &vmName);

    bool startVM(const QString &vmName);

signals:
    void vmRegistered(const QString &vmName, bool isRegistered);
    void vmRunning(const QString &vmName, bool isRunning);
    void vmInfo(const QString &vmName, const VMInfo &vmInfo);
    void progress(const QString &message, int value, bool success);

private slots:
    void processFinished();
    void processError();
    void readyReadStandardOut();
    void readyReadStandardError();
    void checkVMRunning();
    void onConnected();
    void onError(QSsh::SshError error);
    void connectToVM();
    void startVM();
    bool isVMRunning();
    bool isVMRegistered();
    bool getVMInfo();

private:
    void closeConnection();

private:
    VMInfo vmInfoFromOutput();
    bool isVMListed();
    void reset();

private:
    VBoxManagePrivate *d;
    friend class VBoxManagePrivate;
};

} // Internal
} // Mer

#endif // VBOXMANAGE_H
