/****************************************************************************
**
** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#include "vmoptionspage.h"
#include "ui_vmoptionspage.h"
#include "merconstants.h"
#include "merconnectionmanager.h"

#include <utils/fileutils.h>
#include <coreplugin/icore.h>
#include <ssh/sshconnection.h>

#include <QFileDialog>

using namespace QSsh;

namespace Mer {
namespace Internal {

///////////////////////////////////////////////////////////////////////
//
// VMOptionsPage
//
///////////////////////////////////////////////////////////////////////

VMOptionsPage::VMOptionsPage(QObject *parent) :
    MerOptionsPage(parent)
{
    m_settings.fromSettings(Core::ICore::settings());

    setId(QLatin1String(Constants::VM_OPTIONS_ID));
    setDisplayName(QCoreApplication::translate("Mer", Constants::VM_OPTIONS_NAME));
}

QWidget *VMOptionsPage::createPage(QWidget *parent)
{
    m_widget = new VMOptionsWidget(parent);
    m_widget->setSettings(m_settings);
    if (m_searchKeyWords.isEmpty())
        m_searchKeyWords = m_widget->searchKeyWordMatchString();
    return m_widget;
}

void VMOptionsPage::apply()
{
    if (m_widget) {
        const VMSettings newSettings = m_widget->settings();
        if (newSettings != m_settings) {
            m_settings = newSettings;
            m_settings.toSettings(Core::ICore::settings());
        }
    }
}

bool VMOptionsPage::matches(const QString &key) const
{
    return m_searchKeyWords.contains(key, Qt::CaseInsensitive);
}

///////////////////////////////////////////////////////////////////////
//
// VMOptionsWidget
//
///////////////////////////////////////////////////////////////////////

VMOptionsWidget::VMOptionsWidget(QWidget *parent) :
    QWidget(parent),
    m_ui(new Ui::VMOptionsPage)
{
    m_ui->setupUi(this);

    m_ui->testConnectionProgressBar->setHidden(true);
    m_ui->testConnectionProgressBar->setMaximum(VBoxManage::Done);

    connect(m_ui->testConnectionButton, SIGNAL(clicked()), this, SLOT(testConnection()));
    connect(&m_vBoxManage, SIGNAL(progress(QString,int,bool)),
            this, SLOT(showProgress(QString,int)));
}

VMOptionsWidget::~VMOptionsWidget()
{
    delete m_ui;
}

VMSettings VMOptionsWidget::settings() const
{
    VMSettings s;
    s.vmName = m_ui->vmNameLineEdit->text();
    return s;
}

void VMOptionsWidget::setSettings(const VMSettings &s)
{
    m_ui->vmNameLineEdit->setText(s.vmName);
}

QString VMOptionsWidget::searchKeyWordMatchString() const
{
    const QChar blank = QLatin1Char(' ');
    QString keys = m_ui->vmNameLineEdit->text();

    return keys;
}

void VMOptionsWidget::testConnection()
{
    m_ui->testConnectionProgressBar->setHidden(false);
    m_ui->testConnectionProgressBar->setValue(0);
    m_vBoxManage.testSshConnection(m_ui->vmNameLineEdit->text());
}

void VMOptionsWidget::showProgress(const QString &message, int value)
{
    m_ui->testConnectionLabel->setText(message);
    m_ui->testConnectionProgressBar->setValue(value);
}

} // Internal
} // Mer
