/****************************************************************************
**
** Copyright (C) 2012 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#include "vmsettings.h"
#include "merconstants.h"

#include <QSettings>
#include <QDesktopServices>

namespace Mer {
namespace Internal {

const char VM_GROUP[] = "Mer.Options.VM";
const char USERNAME[] = "username";
const char SSH_KEY[] = "sshkey";
const char VM_NAME[] = "vmName";

void VMSettings::toSettings(QSettings *s) const
{
    s->beginGroup(QLatin1String(VM_GROUP));
    s->setValue(QLatin1String(USERNAME), username);
    s->setValue(QLatin1String(SSH_KEY), sshKey);
    s->setValue(QLatin1String(VM_NAME), vmName);
    s->endGroup();
}

void VMSettings::fromSettings(QSettings *s)
{
    s->beginGroup(QLatin1String(VM_GROUP));
    username = s->value(QLatin1String(USERNAME), QLatin1String("mersdk")).toString();
    QString homeFolder = QDesktopServices::storageLocation(QDesktopServices::HomeLocation);
    sshKey = s->value(QLatin1String(SSH_KEY),
                      QString::fromLatin1("%1/.ssh/id_rsa").arg(homeFolder)).toString();
    vmName = s->value(QLatin1String(VM_NAME), QLatin1String("MerSDK")).toString();
    s->endGroup();
}

bool VMSettings::equals(const VMSettings &rhs) const
{
    return username == rhs.username
            && sshKey == rhs.sshKey
            && vmName == rhs.vmName;
}

} // Internal
} // Mer
